==> julynter-0.3.3-py3-none-any.whl: package/lib/linter/options.js <==
import { ErrorTypeKeys, ReportIds, } from './interfaces';
export class AbstractOptionsManager {
    checkReport(key) {
        return this.checks.reports[key];
    }
    checkType(key) {
        return this.checks.types[key];
    }
    checkMode() {
        return this.checks.mode;
    }
    checkRequirements() {
        return this.checks.requirements;
    }
    updateReport(key, value) {
        this.checks.reports[key] = value;
        this.saveKey('report-' + key, value, true);
    }
    updateType(key, value) {
        this.checks.types[key] = value;
        this.saveKey('type-' + key, value, true);
    }
    updateMode(mode) {
        this.checks.mode = mode;
        this.saveKey('mode', mode, true);
    }
    updateRequirements(req) {
        this.checks.requirements = req;
        this.saveKey('requirements', req, true);
    }
    // initialize options, will NOT change notebook metadata
    initializeOptions(checks) {
        this.checks = checks;
    }
    reloadOptions() {
        this.initializeOptions({
            mode: this.loadKey('mode', this.default.mode),
            requirements: this.loadKey('requirements', this.default.requirements),
            reports: ReportIds.reduce((previous, key) => {
                const rkey = 'report-' + key;
                previous[key] = this.loadKey(rkey, this.default.reports[key]);
                return previous;
            }, Object.assign({}, this.default.reports)),
            types: ErrorTypeKeys.reduce((previous, key) => {
                const tkey = 'type-' + key;
                previous[key] = this.loadKey(tkey, this.default.types[key]);
                return previous;
            }, Object.assign({}, this.default.types)),
        });
    }
    saveOptions() {
        this.saveKey('mode', this.checks.mode, false);
        this.saveKey('requirements', this.checks.requirements, false);
        for (const key of ErrorTypeKeys) {
            this.saveKey('type-' + key, this.checks.types[key], false);
        }
        for (const key of ReportIds) {
            this.saveKey('report-' + key, this.checks.reports[key], false);
        }
    }
}

==> julynter-0.4.1-py3-none-any.whl: package/lib/linter/options.js <==
import { ErrorTypeKeys, ReportIds, } from './interfaces';
export class AbstractOptionsManager {
    checkReport(key) {
        return this.checks.reports[key];
    }
    checkType(key) {
        return this.checks.types[key];
    }
    checkMode() {
        return this.checks.mode;
    }
    checkView() {
        return this.checks.view;
    }
    checkRestart() {
        return this.checks.restart;
    }
    checkRequirements() {
        return this.checks.requirements;
    }
    checkFiltered() {
        return this.filteredHashes;
    }
    updateReport(key, value) {
        this.checks.reports[key] = value;
        this.saveKey('report-' + key, value, true);
    }
    updateType(key, value) {
        this.checks.types[key] = value;
        this.saveKey('type-' + key, value, true);
    }
    updateMode(mode) {
        this.checks.mode = mode;
        this.saveKey('mode', mode, true);
    }
    updateView(view) {
        this.checks.view = view;
        this.saveKey('view', view, true);
    }
    updateRestart(restart) {
        this.checks.restart = restart;
        this.saveKey('restart', restart, true);
    }
    updateRequirements(req) {
        this.checks.requirements = req;
        this.saveKey('requirements', req, true);
    }
    resetFiltered() {
        this.filteredHashes = [];
        this.saveKey('filtered-hashes', this.filteredHashes, true);
    }
    addLintFilter(hash) {
        this.filteredHashes.push(hash);
        this.saveKey('filtered-hashes', this.filteredHashes, true);
    }
    // initialize options, will NOT change notebook metadata
    initializeOptions(checks, filteredHashes) {
        this.checks = checks;
        this.filteredHashes = filteredHashes;
    }
    reloadOptions() {
        this.initializeOptions({
            mode: this.loadKey('mode', this.default.mode),
            view: this.loadKey('view', this.default.view),
            restart: this.loadKey('restart', this.default.restart),
            requirements: this.loadKey('requirements', this.default.requirements),
            reports: ReportIds.reduce((previous, key) => {
                const rkey = 'report-' + key;
                previous[key] = this.loadKey(rkey, this.default.reports[key]);
                return previous;
            }, Object.assign({}, this.default.reports)),
            types: ErrorTypeKeys.reduce((previous, key) => {
                const tkey = 'type-' + key;
                previous[key] = this.loadKey(tkey, this.default.types[key]);
                return previous;
            }, Object.assign({}, this.default.types)),
            kernel: this.default.kernel,
        }, this.loadKey('filtered-hashes', []));
    }
    saveOptions() {
        this.saveKey('mode', this.checks.mode, false);
        this.saveKey('view', this.checks.view, false);
        this.saveKey('restart', this.checks.restart, false);
        this.saveKey('requirements', this.checks.requirements, false);
        for (const key of ErrorTypeKeys) {
            this.saveKey('type-' + key, this.checks.types[key], false);
        }
        for (const key of ReportIds) {
            this.saveKey('report-' + key, this.checks.reports[key], false);
        }
        this.saveKey('filtered-hashes', this.filteredHashes, false);
    }
}
